@@ -726,6 +726,10 @@ champlain_view_dispose (GObject *object)
 
   priv->map_layer = NULL;
   priv->license_actor = NULL;
+
+  /* This is needed to prevent race condition see bug #760012 */
+  if (priv->user_layers)
+      clutter_actor_remove_all_children (priv->user_layers);
   priv->user_layers = NULL;
   priv->zoom_layer = NULL;
 
@@ -1417,9 +1421,6 @@ champlain_view_init (ChamplainView *view)
   clutter_actor_set_x_align (priv->license_actor, CLUTTER_ACTOR_ALIGN_END);
   clutter_actor_set_y_align (priv->license_actor, CLUTTER_ACTOR_ALIGN_END);
   clutter_actor_add_child (CLUTTER_ACTOR (view), priv->license_actor);
-  
-  priv->state = CHAMPLAIN_STATE_DONE;
-  g_object_notify (G_OBJECT (view), "state");
 }
 
 
