@@ -210,6 +210,54 @@ append_point (ChamplainPathLayer *layer, gdouble lon, gdouble lat)
   champlain_path_layer_add_node (layer, CHAMPLAIN_LOCATION (coord));
 }
 
+
+static void
+export_to_png_cb (GdkPixbuf    *pixbuf,
+    GAsyncResult *res)
+{
+  gdk_pixbuf_save_to_stream_finish (res, NULL);
+}
+
+
+static void
+export_png (GtkButton     *button,
+    ChamplainView *view)
+{
+  cairo_surface_t *surface;
+  GdkPixbuf *pixbuf;
+  GFileOutputStream *os;
+  GFile *file;
+  gint width, height;
+
+  if (champlain_view_get_state (view) != CHAMPLAIN_STATE_DONE)
+    return;
+
+  surface = champlain_view_to_surface (view, TRUE);
+  if (!surface)
+    return;
+
+  width = cairo_image_surface_get_width (surface);
+  height = cairo_image_surface_get_height (surface);
+  pixbuf = gdk_pixbuf_get_from_surface (surface, 0, 0, width, height);
+  if (!pixbuf)
+    return;
+
+  file = g_file_new_for_path ("champlain-map.png");
+  os = g_file_create (file, G_FILE_CREATE_NONE, NULL, NULL);
+  if (!os)
+    {
+      g_object_unref (pixbuf);
+      return;
+    }
+
+  gdk_pixbuf_save_to_stream_async (pixbuf,
+                                   G_OUTPUT_STREAM (os), "png",
+                                   NULL,
+                                   (GAsyncReadyCallback) export_to_png_cb,
+                                   NULL);
+}
+
+
 static void
 add_clicked (GtkButton     *button,
              ChamplainView *view)
@@ -238,31 +286,33 @@ add_clicked (GtkButton     *button,
 
   response = gtk_dialog_run (GTK_DIALOG (dialog));
 
-  if (response == GTK_RESPONSE_OK) {
-    GtkTreeModel *model;
-    GtkTreeIter iter;
-    ChamplainMapSource *source;
-    ChamplainMapSourceFactory *factory;
-    char *id;
+  if (response == GTK_RESPONSE_OK)
+    {
+      GtkTreeModel *model;
+      GtkTreeIter iter;
+      ChamplainMapSource *source;
+      ChamplainMapSourceFactory *factory;
+      char *id;
 
-    if (!gtk_combo_box_get_active_iter (GTK_COMBO_BOX (combo), &iter))
-      return;
+      if (!gtk_combo_box_get_active_iter (GTK_COMBO_BOX (combo), &iter))
+        return;
 
-    model = gtk_combo_box_get_model (GTK_COMBO_BOX (combo));
+      model = gtk_combo_box_get_model (GTK_COMBO_BOX (combo));
 
-    gtk_tree_model_get (model, &iter, COL_ID, &id, -1);
+      gtk_tree_model_get (model, &iter, COL_ID, &id, -1);
 
-    factory = champlain_map_source_factory_dup_default ();
-    source = champlain_map_source_factory_create_memcached_source (factory, id);
+      factory = champlain_map_source_factory_dup_default ();
+      source = champlain_map_source_factory_create_memcached_source (factory, id);
 
-    champlain_view_add_overlay_source (view, source, 0.6 * 255);
-    g_object_unref (factory);
-    g_free (id);
-  }
+      champlain_view_add_overlay_source (view, source, 0.6 * 255);
+      g_object_unref (factory);
+      g_free (id);
+    }
 
   gtk_widget_destroy (dialog);
 }
 
+
 int
 main (int argc,
     char *argv[])
@@ -382,6 +432,12 @@ main (int argc,
   g_signal_connect (button, "clicked", G_CALLBACK (add_clicked), view);
   gtk_container_add (GTK_CONTAINER (bbox), button);
 
+  button = gtk_button_new ();
+  image = gtk_image_new_from_icon_name ("camera-photo-symbolic", GTK_ICON_SIZE_BUTTON);
+  gtk_button_set_image (GTK_BUTTON (button), image);
+  g_signal_connect (button, "clicked", G_CALLBACK (export_png), view);
+  gtk_container_add (GTK_CONTAINER (bbox), button);
+
   button = gtk_image_new ();
   gtk_widget_set_size_request (button, 22, -1);
   g_signal_connect (view, "notify::state", G_CALLBACK (view_state_changed),
