@@ -121,8 +121,8 @@ class LauncherGTK:
 
     def mouse_click_cb(self, actor, event, view):
         x, y = event.x, event.y
-        lat, lon = view.x_to_longitude(x), view.y_to_latitude(y)
-        print "Mouse click at: %f %f" % (lon, lat)
+        lon, lat = view.x_to_longitude(x), view.y_to_latitude(y)
+        print "Mouse click at: %f %f" % (lat, lon)
         return True
 
     def zoom_changed(self, widget):
